1.0.1 (2026-01-22)
==================

Bug Fixes
---------

- Fix gwcs evaluation when the input or output frames are ``None`` or
  ``EmptyFrame``. (`#684 <https://github.com/spacetelescope/gwcs/issues/684>`_)
